﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;

namespace WC_CompChartLegendTextColor
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            ultraChart1.ChartType = ChartType.Composite;
            ChartArea area = new ChartArea();
            area.BoundsMeasureType = MeasureType.Percentage;
            area.Bounds = new Rectangle(0, 10, 98, 100);

            ultraChart1.CompositeChart.ChartAreas.Add(area);

            // GroupBySeries X axis for columns
            AxisItem axisX = new AxisItem();
            axisX.OrientationType = AxisNumber.X_Axis;
            axisX.DataType = AxisDataType.String;
            axisX.SetLabelAxisType = SetLabelAxisType.GroupBySeries;
            axisX.Labels.ItemFormatString = "<ITEM_LABEL>";
            axisX.Labels.SeriesLabels.Visible = false;
            axisX.Labels.Orientation = TextOrientation.VerticalLeftFacing;

            // ContinuousData X axis for line
            AxisItem axisX2 = new AxisItem();
            axisX2.OrientationType = AxisNumber.X_Axis;
            axisX2.DataType = AxisDataType.String;
            axisX2.Labels.ItemFormatString = "<ITEM_LABEL>";
            axisX2.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            axisX2.Labels.Visible = false;
            axisX2.Visible = false;


            // Y axis for columns
            AxisItem axisY = new AxisItem();
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:0.#>";
            axisY.RangeType = AxisRangeType.Custom;
            axisY.RangeMin = 0;
            axisY.RangeMax = 50;

            // Add series
            NumericSeries firstVolumeSeries = GetVolumeSeries();
            NumericSeries secondVolumeSeries = GetVolumeSeries();
            NumericSeries firstLineSeries = GetFirstLineSeries();
            NumericSeries secondLineSeries = GetSecondLineSeries();
            firstLineSeries.PEs.Add(new PaintElement(Color.Blue));
            secondLineSeries.PEs.Add(new PaintElement(Color.Purple));

            ultraChart1.CompositeChart.Series.Add(firstVolumeSeries);
            ultraChart1.CompositeChart.Series.Add(secondVolumeSeries);
            ultraChart1.CompositeChart.Series.Add(firstLineSeries);
            ultraChart1.CompositeChart.Series.Add(secondLineSeries);

            // Add axes
            area.Axes.Add(axisX);
            area.Axes.Add(axisX2);
            area.Axes.Add(axisY);

            // Create ColumnChart layer
            ChartLayerAppearance columnChartLayer = new ChartLayerAppearance();
            columnChartLayer.ChartType = ChartType.ColumnChart;
            ((ColumnChartAppearance)columnChartLayer.ChartTypeAppearance).SeriesSpacing = 2;
            columnChartLayer.ChartArea = area;
            columnChartLayer.AxisX = axisX;
            columnChartLayer.AxisY = axisY;
            columnChartLayer.LegendItem = LegendItemType.Series;
            columnChartLayer.Series.Add(firstVolumeSeries);
            columnChartLayer.Series.Add(secondVolumeSeries);

            // Create LineChart layer
            ChartLayerAppearance lineChartLayer = new ChartLayerAppearance();
            lineChartLayer.ChartType = ChartType.LineChart;
            LineChartAppearance scatterChart = ((LineChartAppearance)lineChartLayer.ChartTypeAppearance);
            lineChartLayer.LegendItem = LegendItemType.Series;
            lineChartLayer.ChartArea = area;
            lineChartLayer.AxisX = axisX2;
            lineChartLayer.AxisY = axisY;

            lineChartLayer.Series.Add(secondLineSeries);
            lineChartLayer.Series.Add(firstLineSeries);
            

            CompositeLegend myLegend = new CompositeLegend();
            myLegend.ChartLayers.Add(columnChartLayer);
            myLegend.ChartLayers.Add(lineChartLayer);
            myLegend.Bounds = new Rectangle(8, 96, 80, 4);
            myLegend.BoundsMeasureType = MeasureType.Percentage;
            myLegend.LabelStyle.FontSizeBestFit = true;

            myLegend.PE.ElementType = PaintElementType.Gradient;
            myLegend.PE.FillGradientStyle = Infragistics.UltraChart.Shared.Styles.GradientStyle.Circular;
            myLegend.PE.Fill = Color.White;
            myLegend.PE.FillStopColor = Color.White;
            myLegend.Border.CornerRadius = 10;
            myLegend.Border.Thickness = 1;
            myLegend.LabelStyle.FontSizeBestFit = true;
            ultraChart1.Legend.Location = LegendLocation.Bottom;

            this.ultraChart1.CompositeChart.Legends.Add(myLegend);

            // Add layers
            ultraChart1.CompositeChart.ChartLayers.Add(columnChartLayer);
            ultraChart1.CompositeChart.ChartLayers.Add(lineChartLayer);

        }

        private NumericSeries GetFirstLineSeries()
        {
            NumericSeries series = new NumericSeries();
            series.Label = "Series A";
            // this code populates the series using unbound data
            series.Points.Add(new NumericDataPoint(20,  "Point A", false));
            series.Points.Add(new NumericDataPoint(30, "Point B", false));
            series.Points.Add(new NumericDataPoint(40, "Point C", false));
            series.Points.Add(new NumericDataPoint(25, "Point D", false));
            series.Points.Add(new NumericDataPoint(10, "Point E", false));
            series.Points.Add(new NumericDataPoint(20, "Point A", false));
            series.Points.Add(new NumericDataPoint(30, "Point B", false));
            series.Points.Add(new NumericDataPoint(40, "Point C", false));
            series.Points.Add(new NumericDataPoint(25, "Point D", false));
            series.Points.Add(new NumericDataPoint(10, "Point E", false));
            return series;
        }
        private NumericSeries GetSecondLineSeries()
        {
            NumericSeries series = new NumericSeries();
            series.Label = "Series B";
            // this code populates the series using unbound data
            series.Points.Add(new NumericDataPoint(50, "Point A", false));
            series.Points.Add(new NumericDataPoint(10, "Point B", false));
            series.Points.Add(new NumericDataPoint(30, "Point C", false));
            series.Points.Add(new NumericDataPoint(24, "Point D", false));
            series.Points.Add(new NumericDataPoint(12, "Point E", false));
            series.Points.Add(new NumericDataPoint(43, "Point A", false));
            series.Points.Add(new NumericDataPoint(42, "Point B", false));
            series.Points.Add(new NumericDataPoint(10, "Point C", false));
            series.Points.Add(new NumericDataPoint(45, "Point D", false));
            series.Points.Add(new NumericDataPoint(40, "Point E", false));
            return series;
        }

        private NumericSeries GetVolumeSeries()
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("Label", typeof(int));
            dt.Columns.Add("Value", typeof(double));

            dt.Rows.Add(1, 10);
            dt.Rows.Add(2, 20);
            dt.Rows.Add(3, 30);
            dt.Rows.Add(4, 40);
            dt.Rows.Add(5, 20);
            dt.Rows.Add(6, 30);
            dt.Rows.Add(7, 10);
            dt.Rows.Add(8, 20);
            dt.Rows.Add(9, 30);
            dt.Rows.Add(10, 20);

            NumericSeries series1 = new NumericSeries();
            series1.DataBind(dt, "Value", "Label");
            series1.Label = "Column series";

            return series1;
        }


    }
}
